@@ -1,8 +1,9 @@
 import requests
+import sys
 
 from .adapters import UnixAdapter
 
-__all__ = ['monkeypatch', 'Session', 'UnixAdapter']
+__all__ = ['monkeypatch', 'Session']
 
 DEFAULT_SCHEME = 'http+unix://'
 
@@ -14,14 +15,18 @@ class Session(requests.Session):
 
 
 class monkeypatch(object):
-    def __init__(self, url_scheme):
-        self.session = requests.Session()
-        self.session.mount(url_scheme, UnixAdapter())
+    def __init__(self, url_scheme=DEFAULT_SCHEME):
+        self.session = Session()
+        requests = self._get_global_requests_module()
         self.orig_requests_get = requests.get
         requests.get = self.session.get
 
+    def _get_global_requests_module(self):
+        return sys.modules['requests']
+
     def __enter__(self):
         return self
 
     def __exit__(self, *args):
+        requests = self._get_global_requests_module()
         requests.get = self.orig_requests_get
